==> haskell-authenticate-1.3.5-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.5
id: authenticate-1.3.5-E49ZLG2SUAz3FOnZEatX4c
key: authenticate-1.3.5-E49ZLG2SUAz3FOnZEatX4c
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
abi: 62b82df7c53f20e0bd1069ad2d372044
exposed: True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
import-dirs: /usr/lib/ghc-8.6.5/site-local/authenticate-1.3.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/authenticate-1.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/authenticate-1.3.5
hs-libraries: HSauthenticate-1.3.5-E49ZLG2SUAz3FOnZEatX4c
depends:
    aeson-1.4.6.0-53gmO5YtU8gIZiWG8EtnAc
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    conduit-1.3.1.1-223VZeefHKZIaNcv3a4V93 containers-0.6.0.1
    html-conduit-1.3.2.1-Lp9qCxBcWrj5NyqvNa3zN7
    http-conduit-2.3.7.3-FS1jUUT66Fg5QWgfhc60lE
    http-types-0.12.3-KiHBR3VW7LN81D4RBDuP1U
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
    xml-conduit-1.8.0.1-FQgjHYTgeAaEJlEXblYKrJ
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.5-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.5
id: authenticate-1.3.5-7nV6QHEt8mMHZGw7Vbur3a
key: authenticate-1.3.5-7nV6QHEt8mMHZGw7Vbur3a
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
abi: 8e359634776848c6dc9b3ca1ea0de322
exposed: True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
import-dirs: /usr/lib/ghc-8.6.5/site-local/authenticate-1.3.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/authenticate-1.3.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/authenticate-1.3.5
hs-libraries: HSauthenticate-1.3.5-7nV6QHEt8mMHZGw7Vbur3a
depends:
    aeson-1.4.6.0-53gmO5YtU8gIZiWG8EtnAc
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    conduit-1.3.1.1-FcGmdT7SxdEGYrdumpBUzp containers-0.6.0.1
    html-conduit-1.3.2.1-92BiZrYQzja60t6hNB63bd
    http-conduit-2.3.7.3-4YxTuEsiEOn8OcaFG8W8p2
    http-types-0.12.3-KiHBR3VW7LN81D4RBDuP1U
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
    xml-conduit-1.8.0.1-JafVFc5sNpjAeRhdjd9fzm
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
